@@ -303,10 +303,10 @@ module Net
             data = data[0,window_size]
           end
 
-          if data.length + overhead > maximum_packet_size
-            data_to_return = data[maximum_packet_size..-1] + 
-              ( data_to_return || "" )
-            data = data[0,maximum_packet_size]
+          max_size_less_overhead = maximum_packet_size - overhead
+          if data.length > max_size_less_overhead
+            data_to_return = data[max_size_less_overhead..-1] + ( data_to_return || "" )
+            data = data[0,max_size_less_overhead]
           end
 
           [ data, data_to_return ]
