@@ -204,6 +204,17 @@ module Net
         end
         private :agent_failed
 
+        def send_raw_packet( data )
+          @socket.send data, 0
+        end
+        
+        def read_raw_packet
+          buffer = @socket.read( 4 )
+          length = buffer.unpack( "N" ).first
+          buffer = buffer + @socket.read( length )
+          buffer
+        end
+
       end
 
     end
