@@ -87,7 +87,7 @@ module Net
                   msg = @buffers.writer
                   msg.write_byte USERAUTH_INFO_RESPONSE
                   msg.write_long responses.length
-                  msg.write_string *responses
+                  msg.write_string(*responses)
                   @messenger.send_message msg
                 else
                   raise Net::SSH::Exception,
