@@ -126,7 +126,7 @@ module Net
               driver.set_host_key_files c[:userauth_host_keys]
             end
             if c.knows_key?(:userauth_method_order) && c[:userauth_method_order]
-              driver.set_auth_method_order *c[:userauth_method_order]
+              driver.set_auth_method_order(*c[:userauth_method_order])
             end
 
             driver
