@@ -20,6 +20,7 @@ if $run_integration_tests || __FILE__ == $0
 
   require 'needle'
   require 'test/unit'
+  require 'net/ssh/null-host-key-verifier'
 
   class TC_Process_Integration < Test::Unit::TestCase
 
@@ -39,6 +40,7 @@ if $run_integration_tests || __FILE__ == $0
         
         b.crypto_backend { :ossl }
         b.transport_host { HOST }
+        b.host_key_verifier { Net::SSH::NullHostKeyVerifier.new }
       end
 
       @registry.userauth.driver.authenticate( "ssh-connection", USER, PASSWORD )
