@@ -17,6 +17,7 @@
 $:.unshift "#{File.dirname(__FILE__)}/../../../lib"
 
 require 'net/ssh/errors'
+require 'net/ssh/null-host-key-verifier'
 require 'net/ssh/transport/kex/dh'
 require 'net/ssh/util/buffer'
 require 'test/unit'
@@ -131,6 +132,10 @@ class TC_KEX_DH < Test::Unit::TestCase
       [ @script.shift, @script.shift ]
     end
 
+    def peer
+      {}
+    end
+
     def algorithms
       OpenStruct.new( :host_key => "ssh-test" )
     end
@@ -141,6 +146,7 @@ class TC_KEX_DH < Test::Unit::TestCase
       MockBNs.new, MockDigests.new )
     @kex.keys = MockKeys.new
     @kex.buffers = MockBuffers.new
+    @kex.host_key_verifier = Net::SSH::NullHostKeyVerifier.new
 
     @init  = Net::SSH::Transport::Kex::DiffieHellmanGroup1SHA1::KEXDH_INIT
     @reply = Net::SSH::Transport::Kex::DiffieHellmanGroup1SHA1::KEXDH_REPLY
