@@ -98,7 +98,7 @@ class TC_Session < Test::Unit::TestCase
       @on_new_algos = block
     end
     def set_algorithms( *args )
-      @on_new_algos.call *args if @on_new_algos
+      @on_new_algos.call(*args) if @on_new_algos
     end
   end
 
